@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -16,9 +16,12 @@
  */
 package org.apache.commons.lang3;
 
+import static org.apache.commons.lang3.LangAssertions.assertIllegalArgumentException;
+import static org.apache.commons.lang3.LangAssertions.assertNullPointerException;
 import static org.junit.jupiter.api.Assertions.assertArrayEquals;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertInstanceOf;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertNotSame;
 import static org.junit.jupiter.api.Assertions.assertNull;
@@ -47,16 +50,18 @@ import java.util.Set;
 import java.util.function.Supplier;
 
 import org.apache.commons.lang3.exception.CloneFailedException;
+import org.apache.commons.lang3.function.Suppliers;
 import org.apache.commons.lang3.mutable.MutableInt;
 import org.apache.commons.lang3.mutable.MutableObject;
 import org.apache.commons.lang3.text.StrBuilder;
 import org.junit.jupiter.api.Test;
 
 /**
- * Unit tests {@link org.apache.commons.lang3.ObjectUtils}.
+ * Tests {@link ObjectUtils}.
  */
 @SuppressWarnings("deprecation") // deliberate use of deprecated code
-public class ObjectUtilsTest extends AbstractLangTest {
+class ObjectUtilsTest extends AbstractLangTest {
+
     static final class CharSequenceComparator implements Comparator<CharSequence> {
 
         @Override
@@ -125,6 +130,8 @@ public class ObjectUtilsTest extends AbstractLangTest {
         }
     }
 
+    private static final Supplier<?> NULL_SUPPLIER = null;
+
     private static final String FOO = "foo";
     private static final String BAR = "bar";
     private static final String[] NON_EMPTY_ARRAY = { FOO, BAR, };
@@ -143,7 +150,7 @@ public class ObjectUtilsTest extends AbstractLangTest {
      * Tests {@link ObjectUtils#allNotNull(Object...)}.
      */
     @Test
-    public void testAllNotNull() {
+    void testAllNotNull() {
         assertFalse(ObjectUtils.allNotNull((Object) null));
         assertFalse(ObjectUtils.allNotNull((Object[]) null));
         assertFalse(ObjectUtils.allNotNull(null, null, null));
@@ -160,7 +167,7 @@ public class ObjectUtilsTest extends AbstractLangTest {
      * Tests {@link ObjectUtils#allNull(Object...)}.
      */
     @Test
-    public void testAllNull() {
+    void testAllNull() {
         assertTrue(ObjectUtils.allNull());
         assertTrue(ObjectUtils.allNull((Object) null));
         assertTrue(ObjectUtils.allNull((Object[]) null));
@@ -175,7 +182,7 @@ public class ObjectUtilsTest extends AbstractLangTest {
      * Tests {@link ObjectUtils#anyNotNull(Object...)}.
      */
     @Test
-    public void testAnyNotNull() {
+    void testAnyNotNull() {
         assertFalse(ObjectUtils.anyNotNull());
         assertFalse(ObjectUtils.anyNotNull((Object) null));
         assertFalse(ObjectUtils.anyNotNull((Object[]) null));
@@ -190,7 +197,7 @@ public class ObjectUtilsTest extends AbstractLangTest {
      * Tests {@link ObjectUtils#anyNull(Object...)}.
      */
     @Test
-    public void testAnyNull() {
+    void testAnyNull() {
         assertTrue(ObjectUtils.anyNull((Object) null));
         assertTrue(ObjectUtils.anyNull(null, null, null));
         assertTrue(ObjectUtils.anyNull(null, FOO, BAR));
@@ -206,7 +213,7 @@ public class ObjectUtilsTest extends AbstractLangTest {
      * Test for {@link ObjectUtils#isArray(Object)}.
      */
     @Test
-    public void testArray() {
+    void testArray() {
         assertFalse(ObjectUtils.isArray(null));
         assertFalse(ObjectUtils.isArray(""));
         assertFalse(ObjectUtils.isArray("abg"));
@@ -243,17 +250,17 @@ public class ObjectUtilsTest extends AbstractLangTest {
      * Tests {@link ObjectUtils#clone(Object)} with a cloneable object.
      */
     @Test
-    public void testCloneOfCloneable() {
+    void testCloneOfCloneable() {
         final CloneableString string = new CloneableString("apache");
         final CloneableString stringClone = ObjectUtils.clone(string);
-        assertEquals("apache", stringClone.getValue());
+        assertEquals("apache", stringClone.get());
     }
 
     /**
      * Tests {@link ObjectUtils#clone(Object)} with a not cloneable object.
      */
     @Test
-    public void testCloneOfNotCloneable() {
+    void testCloneOfNotCloneable() {
         final String string = "apache";
         assertNull(ObjectUtils.clone(string));
     }
@@ -262,7 +269,7 @@ public class ObjectUtilsTest extends AbstractLangTest {
      * Tests {@link ObjectUtils#clone(Object)} with an array of primitives.
      */
     @Test
-    public void testCloneOfPrimitiveArray() {
+    void testCloneOfPrimitiveArray() {
         assertArrayEquals(new int[]{1}, ObjectUtils.clone(new int[]{1}));
     }
 
@@ -270,7 +277,7 @@ public class ObjectUtilsTest extends AbstractLangTest {
      * Tests {@link ObjectUtils#clone(Object)} with an object array.
      */
     @Test
-    public void testCloneOfStringArray() {
+    void testCloneOfStringArray() {
         assertTrue(Arrays.deepEquals(
             new String[]{"string"}, ObjectUtils.clone(new String[]{"string"})));
     }
@@ -279,14 +286,16 @@ public class ObjectUtilsTest extends AbstractLangTest {
      * Tests {@link ObjectUtils#clone(Object)} with an uncloneable object.
      */
     @Test
-    public void testCloneOfUncloneable() {
+    void testCloneOfUncloneable() {
         final UncloneableString string = new UncloneableString("apache");
         final CloneFailedException e = assertThrows(CloneFailedException.class, () -> ObjectUtils.clone(string));
+        assertNotNull(e);
+        assertNotNull(e.getCause());
         assertEquals(NoSuchMethodException.class, e.getCause().getClass());
     }
 
     @Test
-    public void testComparatorMedian() {
+    void testComparatorMedian() {
         final CharSequenceComparator cmp = new CharSequenceComparator();
         final NonComparableCharSequence foo = new NonComparableCharSequence("foo");
         final NonComparableCharSequence bar = new NonComparableCharSequence("bar");
@@ -301,19 +310,19 @@ public class ObjectUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testComparatorMedian_emptyItems() {
-        assertThrows(IllegalArgumentException.class, () -> ObjectUtils.median(new CharSequenceComparator()));
+    void testComparatorMedian_emptyItems() {
+        assertIllegalArgumentException(() -> ObjectUtils.median(new CharSequenceComparator()));
     }
 
     @Test
-    public void testComparatorMedian_nullComparator() {
-        assertThrows(NullPointerException.class,
+    void testComparatorMedian_nullComparator() {
+        assertNullPointerException(
                 () -> ObjectUtils.median((Comparator<CharSequence>) null, new NonComparableCharSequence("foo")));
     }
 
     @Test
-    public void testComparatorMedian_nullItems() {
-        assertThrows(NullPointerException.class,
+    void testComparatorMedian_nullItems() {
+        assertNullPointerException(
                 () -> ObjectUtils.median(new CharSequenceComparator(), (CharSequence[]) null));
     }
 
@@ -321,7 +330,7 @@ public class ObjectUtilsTest extends AbstractLangTest {
      * Tests {@link ObjectUtils#compare(Comparable, Comparable, boolean)}.
      */
     @Test
-    public void testCompare() {
+    void testCompare() {
         final Integer one = Integer.valueOf(1);
         final Integer two = Integer.valueOf(2);
         final Integer nullValue = null;
@@ -340,12 +349,10 @@ public class ObjectUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testConstMethods() {
-
+    void testConstMethods() {
         // To truly test the CONST() method, we'd want to look in the
         // bytecode to see if the literals were folded into the
         // class, or if the bytecode kept the method call.
-
         assertTrue(ObjectUtils.CONST(true), "CONST(boolean)");
         assertEquals((byte) 3, ObjectUtils.CONST((byte) 3), "CONST(byte)");
         assertEquals((char) 3, ObjectUtils.CONST((char) 3), "CONST(char)");
@@ -355,13 +362,12 @@ public class ObjectUtilsTest extends AbstractLangTest {
         assertEquals(3f, ObjectUtils.CONST(3f), "CONST(float)");
         assertEquals(3.0, ObjectUtils.CONST(3.0), "CONST(double)");
         assertEquals("abc", ObjectUtils.CONST("abc"), "CONST(Object)");
-
         // Make sure documentation examples from Javadoc all work
         // (this fixed a lot of my bugs when I these!)
         //
         // My bugs should be in a software engineering textbook
-        // for "Can you screw this up?"  The answer is, yes,
-        // you can even screw this up.  (When you == Julius)
+        // for "Can you screw this up?" The answer is, yes,
+        // you can even screw this up. (When you == Julius)
         // .
         final boolean MAGIC_FLAG = ObjectUtils.CONST(true);
         final byte MAGIC_BYTE1 = ObjectUtils.CONST((byte) 127);
@@ -375,7 +381,6 @@ public class ObjectUtilsTest extends AbstractLangTest {
         final float MAGIC_FLOAT = ObjectUtils.CONST(1.0f);
         final double MAGIC_DOUBLE = ObjectUtils.CONST(1.0);
         final String MAGIC_STRING = ObjectUtils.CONST("abc");
-
         assertTrue(MAGIC_FLAG);
         assertEquals(127, MAGIC_BYTE1);
         assertEquals(127, MAGIC_BYTE2);
@@ -388,26 +393,16 @@ public class ObjectUtilsTest extends AbstractLangTest {
         assertEquals(1.0f, MAGIC_FLOAT);
         assertEquals(1.0, MAGIC_DOUBLE);
         assertEquals("abc", MAGIC_STRING);
-        assertThrows(
-                IllegalArgumentException.class,
-                () -> ObjectUtils.CONST_BYTE(-129),
-                "CONST_BYTE(-129): IllegalArgumentException should have been thrown.");
-        assertThrows(
-                IllegalArgumentException.class,
-                () -> ObjectUtils.CONST_BYTE(128),
-                "CONST_BYTE(128): IllegalArgumentException should have been thrown.");
-        assertThrows(
-                IllegalArgumentException.class,
-                () -> ObjectUtils.CONST_SHORT(-32769),
+        assertIllegalArgumentException(() -> ObjectUtils.CONST_BYTE(-129), "CONST_BYTE(-129): IllegalArgumentException should have been thrown.");
+        assertIllegalArgumentException(() -> ObjectUtils.CONST_BYTE(128), "CONST_BYTE(128): IllegalArgumentException should have been thrown.");
+        assertIllegalArgumentException(() -> ObjectUtils.CONST_SHORT(-32769),
                 "CONST_SHORT(-32769): IllegalArgumentException should have been thrown.");
-        assertThrows(
-                IllegalArgumentException.class,
-                () -> ObjectUtils.CONST_BYTE(32768),
+        assertIllegalArgumentException(() -> ObjectUtils.CONST_BYTE(32768),
                 "CONST_SHORT(32768): IllegalArgumentException should have been thrown.");
     }
 
     @Test
-    public void testConstructor() {
+    void testConstructor() {
         assertNotNull(new ObjectUtils());
         final Constructor<?>[] cons = ObjectUtils.class.getDeclaredConstructors();
         assertEquals(1, cons.length);
@@ -417,7 +412,7 @@ public class ObjectUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testDefaultIfNull() {
+    void testDefaultIfNull() {
         final Object o = FOO;
         final Object dflt = BAR;
         assertSame(dflt, ObjectUtils.defaultIfNull(null, dflt), "dflt was not returned when o was null");
@@ -432,13 +427,13 @@ public class ObjectUtilsTest extends AbstractLangTest {
             return dflt;
         };
         ObjectUtils.getIfNull(o, countingDefaultSupplier);
-        assertEquals(0, callsCounter.getValue());
+        assertEquals(0, callsCounter.get());
         ObjectUtils.getIfNull(null, countingDefaultSupplier);
-        assertEquals(1, callsCounter.getValue());
+        assertEquals(1, callsCounter.get());
     }
 
     @Test
-    public void testEquals() {
+    void testEquals() {
         assertTrue(ObjectUtils.equals(null, null), "ObjectUtils.equals(null, null) returned false");
         assertFalse(ObjectUtils.equals(FOO, null), "ObjectUtils.equals(\"foo\", null) returned true");
         assertFalse(ObjectUtils.equals(null, BAR), "ObjectUtils.equals(null, \"bar\") returned true");
@@ -447,7 +442,7 @@ public class ObjectUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testFirstNonNull() {
+    void testFirstNonNull() {
         assertEquals("", ObjectUtils.firstNonNull(null, ""));
         final String firstNonNullGenerics = ObjectUtils.firstNonNull(null, null, "123", "456");
         assertEquals("123", firstNonNullGenerics);
@@ -465,7 +460,7 @@ public class ObjectUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testGetClass() {
+    void testGetClass() {
         final String[] newArray = ArrayUtils.EMPTY_STRING_ARRAY;
         // No type-cast required.
         final Class<String[]> cls = ObjectUtils.getClass(newArray);
@@ -474,16 +469,17 @@ public class ObjectUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testGetFirstNonNull() {
+    void testGetFirstNonNull() {
         // first non-null
-        assertEquals("", ObjectUtils.getFirstNonNull(() -> null, () -> ""));
+        assertEquals("", ObjectUtils.getFirstNonNull(null, () -> ""));
+        assertEquals("", ObjectUtils.getFirstNonNull(Suppliers.nul(), () -> ""));
         // first encountered value is used
-        assertEquals("1", ObjectUtils.getFirstNonNull(() -> null, () -> "1", () -> "2", () -> null));
-        assertEquals("123", ObjectUtils.getFirstNonNull(() -> "123", () -> null, () -> "456"));
+        assertEquals("1", ObjectUtils.getFirstNonNull(Suppliers.nul(), () -> "1", () -> "2", Suppliers.nul()));
+        assertEquals("123", ObjectUtils.getFirstNonNull(() -> "123", Suppliers.nul(), () -> "456"));
         // don't evaluate suppliers after first value is found
-        assertEquals("123", ObjectUtils.getFirstNonNull(() -> null, () -> "123", () -> fail("Supplier after first non-null value should not be evaluated")));
+        assertEquals("123", ObjectUtils.getFirstNonNull(Suppliers.nul(), () -> "123", () -> fail("Supplier after first non-null value should not be evaluated")));
         // supplier returning null and null supplier both result in null
-        assertNull(ObjectUtils.getFirstNonNull(null, () -> null));
+        assertNull(ObjectUtils.getFirstNonNull(null, Suppliers.nul()));
         // Explicitly pass in an empty array of Object type to ensure compiler doesn't complain of unchecked generic array creation
         assertNull(ObjectUtils.getFirstNonNull());
         // supplier is null
@@ -491,18 +487,47 @@ public class ObjectUtilsTest extends AbstractLangTest {
         // varargs array itself is null
         assertNull(ObjectUtils.getFirstNonNull((Supplier<Object>[]) null));
         // test different types
-        assertEquals(1, ObjectUtils.getFirstNonNull(() -> null, () -> 1));
-        assertEquals(Boolean.TRUE, ObjectUtils.getFirstNonNull(() -> null, () -> Boolean.TRUE));
+        assertEquals(1, ObjectUtils.getFirstNonNull(Suppliers.nul(), () -> 1));
+        assertEquals(Boolean.TRUE, ObjectUtils.getFirstNonNull(Suppliers.nul(), () -> Boolean.TRUE));
     }
 
     @Test
-    public void testHashCode() {
+    void testGetIfNullObject() {
+        final Object o = FOO;
+        final Object defaultObject = BAR;
+        assertNull(ObjectUtils.getIfNull(null, (Object) null));
+        assertSame(defaultObject, ObjectUtils.getIfNull(null, defaultObject), "dflt was not returned when o was null");
+        assertSame(o, ObjectUtils.getIfNull(o, defaultObject), "dflt was returned when o was not null");
+    }
+
+    @Test
+    void testGetIfNullSupplier() {
+        final Object o = FOO;
+        final Object defaultObject = BAR;
+        assertNull(ObjectUtils.getIfNull(null, (Supplier<Object>) null));
+        assertSame(defaultObject, ObjectUtils.getIfNull(null, () -> defaultObject), "dflt was not returned when o was null");
+        assertSame(o, ObjectUtils.getIfNull(o, () -> defaultObject), "dflt was returned when o was not null");
+        assertSame(o, ObjectUtils.getIfNull(FOO, () -> defaultObject), "dflt was returned when o was not null");
+        assertSame(o, ObjectUtils.getIfNull("foo", () -> defaultObject), "dflt was returned when o was not null");
+        final MutableInt callsCounter = new MutableInt(0);
+        final Supplier<Object> countingDefaultSupplier = () -> {
+            callsCounter.increment();
+            return defaultObject;
+        };
+        ObjectUtils.getIfNull(o, countingDefaultSupplier);
+        assertEquals(0, callsCounter.get());
+        ObjectUtils.getIfNull(null, countingDefaultSupplier);
+        assertEquals(1, callsCounter.get());
+    }
+
+    @Test
+    void testHashCode() {
         assertEquals(0, ObjectUtils.hashCode(null));
         assertEquals("a".hashCode(), ObjectUtils.hashCode("a"));
     }
 
     @Test
-    public void testHashCodeHex() {
+    void testHashCodeHex() {
         final Integer i = Integer.valueOf(90);
         assertEquals(Integer.toHexString(Objects.hashCode(i)), ObjectUtils.hashCodeHex(i));
         final Integer zero = Integer.valueOf(0);
@@ -511,13 +536,13 @@ public class ObjectUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testHashCodeMulti_multiple_emptyArray() {
+    void testHashCodeMulti_multiple_emptyArray() {
         final Object[] array = {};
         assertEquals(1, ObjectUtils.hashCodeMulti(array));
     }
 
     @Test
-    public void testHashCodeMulti_multiple_likeList() {
+    void testHashCodeMulti_multiple_likeList() {
         final List<Object> list0 = new ArrayList<>(Collections.emptyList());
         assertEquals(list0.hashCode(), ObjectUtils.hashCodeMulti());
 
@@ -532,13 +557,13 @@ public class ObjectUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testHashCodeMulti_multiple_nullArray() {
+    void testHashCodeMulti_multiple_nullArray() {
         final Object[] array = null;
         assertEquals(1, ObjectUtils.hashCodeMulti(array));
     }
 
     @Test
-    public void testIdentityHashCodeHex() {
+    void testIdentityHashCodeHex() {
         final Integer i = Integer.valueOf(90);
         assertEquals(Integer.toHexString(System.identityHashCode(i)), ObjectUtils.identityHashCodeHex(i));
         final Integer zero = Integer.valueOf(0);
@@ -547,23 +572,18 @@ public class ObjectUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testIdentityToStringAppendable() throws IOException {
+    void testIdentityToStringAppendable() throws IOException {
         final Integer i = Integer.valueOf(121);
         final String expected = "java.lang.Integer@" + Integer.toHexString(System.identityHashCode(i));
-
         final Appendable appendable = new StringBuilder();
         ObjectUtils.identityToString(appendable, i);
         assertEquals(expected, appendable.toString());
-
-        assertThrows(NullPointerException.class, () -> ObjectUtils.identityToString((Appendable) null, "tmp"));
-
-        assertThrows(
-                NullPointerException.class,
-                () -> ObjectUtils.identityToString((Appendable) (new StringBuilder()), null));
+        assertNullPointerException(() -> ObjectUtils.identityToString((Appendable) null, "tmp"));
+        assertNullPointerException(() -> ObjectUtils.identityToString((Appendable) new StringBuilder(), null));
     }
 
     @Test
-    public void testIdentityToStringInteger() {
+    void testIdentityToStringInteger() {
         final Integer i = Integer.valueOf(90);
         final String expected = "java.lang.Integer@" + Integer.toHexString(System.identityHashCode(i));
 
@@ -571,46 +591,41 @@ public class ObjectUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testIdentityToStringObjectNull() {
+    void testIdentityToStringObjectNull() {
         assertNull(ObjectUtils.identityToString(null));
     }
 
     @Test
-    public void testIdentityToStringStrBuilder() {
+    void testIdentityToStringStrBuilder() {
         final Integer i = Integer.valueOf(102);
         final String expected = "java.lang.Integer@" + Integer.toHexString(System.identityHashCode(i));
-
         final StrBuilder builder = new StrBuilder();
         ObjectUtils.identityToString(builder, i);
         assertEquals(expected, builder.toString());
-
-        assertThrows(NullPointerException.class, () -> ObjectUtils.identityToString((StrBuilder) null, "tmp"));
-
-        assertThrows(NullPointerException.class, () -> ObjectUtils.identityToString(new StrBuilder(), null));
+        assertNullPointerException(() -> ObjectUtils.identityToString((StrBuilder) null, "tmp"));
+        assertNullPointerException(() -> ObjectUtils.identityToString(new StrBuilder(), null));
     }
 
     @Test
-    public void testIdentityToStringString() {
+    void testIdentityToStringString() {
         assertEquals(
                 "java.lang.String@" + Integer.toHexString(System.identityHashCode(FOO)),
                 ObjectUtils.identityToString(FOO));
     }
 
     @Test
-    public void testIdentityToStringStringBuffer() {
+    void testIdentityToStringStringBuffer() {
         final Integer i = Integer.valueOf(45);
         final String expected = "java.lang.Integer@" + Integer.toHexString(System.identityHashCode(i));
-
         final StringBuffer buffer = new StringBuffer();
         ObjectUtils.identityToString(buffer, i);
         assertEquals(expected, buffer.toString());
-
-        assertThrows(NullPointerException.class, () -> ObjectUtils.identityToString((StringBuffer) null, "tmp"));
-        assertThrows(NullPointerException.class, () -> ObjectUtils.identityToString(new StringBuffer(), null));
+        assertNullPointerException(() -> ObjectUtils.identityToString((StringBuffer) null, "tmp"));
+        assertNullPointerException(() -> ObjectUtils.identityToString(new StringBuffer(), null));
     }
 
     @Test
-    public void testIdentityToStringStringBuilder() {
+    void testIdentityToStringStringBuilder() {
         final Integer i = Integer.valueOf(90);
         final String expected = "java.lang.Integer@" + Integer.toHexString(System.identityHashCode(i));
 
@@ -620,10 +635,9 @@ public class ObjectUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testIdentityToStringStringBuilderInUse() {
+    void testIdentityToStringStringBuilderInUse() {
         final Integer i = Integer.valueOf(90);
         final String expected = "ABC = java.lang.Integer@" + Integer.toHexString(System.identityHashCode(i));
-
         final StringBuilder builder = new StringBuilder("ABC = ");
         ObjectUtils.identityToString(builder, i);
         assertEquals(expected, builder.toString());
@@ -631,16 +645,16 @@ public class ObjectUtilsTest extends AbstractLangTest {
 
     @Test
     public  void testIdentityToStringStringBuilderNullStringBuilder() {
-        assertThrows(NullPointerException.class, () -> ObjectUtils.identityToString((StringBuilder) null, "tmp"));
+        assertNullPointerException(() -> ObjectUtils.identityToString((StringBuilder) null, "tmp"));
     }
 
     @Test
-    public void testIdentityToStringStringBuilderNullValue() {
-        assertThrows(NullPointerException.class, () -> ObjectUtils.identityToString(new StringBuilder(), null));
+    void testIdentityToStringStringBuilderNullValue() {
+        assertNullPointerException(() -> ObjectUtils.identityToString(new StringBuilder(), null));
     }
 
     @Test
-    public void testIsEmpty() {
+    void testIsEmpty() {
         assertTrue(ObjectUtils.isEmpty(null));
         assertTrue(ObjectUtils.isEmpty(""));
         assertTrue(ObjectUtils.isEmpty(new int[] {}));
@@ -661,7 +675,7 @@ public class ObjectUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testIsNotEmpty() {
+    void testIsNotEmpty() {
         assertFalse(ObjectUtils.isNotEmpty(null));
         assertFalse(ObjectUtils.isNotEmpty(""));
         assertFalse(ObjectUtils.isNotEmpty(new int[] {}));
@@ -682,7 +696,7 @@ public class ObjectUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testMax() {
+    void testMax() {
         final Calendar calendar = Calendar.getInstance();
         final Date nonNullComparable1 = calendar.getTime();
         final Date nonNullComparable2 = calendar.getTime();
@@ -708,7 +722,7 @@ public class ObjectUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testMedian() {
+    void testMedian() {
         assertEquals("foo", ObjectUtils.median("foo"));
         assertEquals("bar", ObjectUtils.median("foo", "bar"));
         assertEquals("baz", ObjectUtils.median("foo", "bar", "baz"));
@@ -725,17 +739,17 @@ public class ObjectUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testMedian_emptyItems() {
-        assertThrows(IllegalArgumentException.class, ObjectUtils::<String>median);
+    void testMedian_emptyItems() {
+        assertIllegalArgumentException(ObjectUtils::<String>median);
     }
 
     @Test
-    public void testMedian_nullItems() {
-        assertThrows(NullPointerException.class, () -> ObjectUtils.median((String[]) null));
+    void testMedian_nullItems() {
+        assertNullPointerException(() -> ObjectUtils.median((String[]) null));
     }
 
     @Test
-    public void testMin() {
+    void testMin() {
         final Calendar calendar = Calendar.getInstance();
         final Date nonNullComparable1 = calendar.getTime();
         final Date nonNullComparable2 = calendar.getTime();
@@ -761,7 +775,7 @@ public class ObjectUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testMode() {
+    void testMode() {
         assertNull(ObjectUtils.mode((Object[]) null));
         assertNull(ObjectUtils.mode());
         assertNull(ObjectUtils.mode("foo", "bar", "baz"));
@@ -772,7 +786,7 @@ public class ObjectUtilsTest extends AbstractLangTest {
     }
 
     @Test
-    public void testNotEqual() {
+    void testNotEqual() {
         assertFalse(ObjectUtils.notEqual(null, null), "ObjectUtils.notEqual(null, null) returned false");
         assertTrue(ObjectUtils.notEqual(FOO, null), "ObjectUtils.notEqual(\"foo\", null) returned true");
         assertTrue(ObjectUtils.notEqual(null, BAR), "ObjectUtils.notEqual(null, \"bar\") returned true");
@@ -782,10 +796,10 @@ public class ObjectUtilsTest extends AbstractLangTest {
 
     @SuppressWarnings("cast") // 1 OK, because we are checking for code change
     @Test
-    public void testNull() {
+    void testNull() {
         assertNotNull(ObjectUtils.NULL);
         // 1 Check that NULL really is a Null i.e. the definition has not been changed
-        assertTrue(ObjectUtils.NULL instanceof ObjectUtils.Null);
+        assertInstanceOf(ObjectUtils.Null.class, ObjectUtils.NULL);
         assertSame(ObjectUtils.NULL, SerializationUtils.clone(ObjectUtils.NULL));
     }
 
@@ -793,17 +807,17 @@ public class ObjectUtilsTest extends AbstractLangTest {
      * Tests {@link ObjectUtils#cloneIfPossible(Object)} with a cloneable object.
      */
     @Test
-    public void testPossibleCloneOfCloneable() {
+    void testPossibleCloneOfCloneable() {
         final CloneableString string = new CloneableString("apache");
         final CloneableString stringClone = ObjectUtils.cloneIfPossible(string);
-        assertEquals("apache", stringClone.getValue());
+        assertEquals("apache", stringClone.get());
     }
 
     /**
      * Tests {@link ObjectUtils#cloneIfPossible(Object)} with a not cloneable object.
      */
     @Test
-    public void testPossibleCloneOfNotCloneable() {
+    void testPossibleCloneOfNotCloneable() {
         final String string = "apache";
         assertSame(string, ObjectUtils.cloneIfPossible(string));
     }
@@ -812,48 +826,61 @@ public class ObjectUtilsTest extends AbstractLangTest {
      * Tests {@link ObjectUtils#cloneIfPossible(Object)} with an uncloneable object.
      */
     @Test
-    public void testPossibleCloneOfUncloneable() {
+    void testPossibleCloneOfUncloneable() {
         final UncloneableString string = new UncloneableString("apache");
-        final CloneFailedException e = assertThrows(CloneFailedException.class,
-                () -> ObjectUtils.cloneIfPossible(string));
+        final CloneFailedException e = assertThrows(CloneFailedException.class, () -> ObjectUtils.cloneIfPossible(string));
+        assertNotNull(e);
+        assertNotNull(e.getCause());
         assertEquals(NoSuchMethodException.class, e.getCause().getClass());
     }
 
     @Test
-    public void testRequireNonEmpty() {
+    void testRequireNonEmpty() {
         assertEquals("foo", ObjectUtils.requireNonEmpty("foo"));
         assertEquals("foo", ObjectUtils.requireNonEmpty("foo", "foo"));
         //
-        assertThrows(NullPointerException.class, () -> ObjectUtils.requireNonEmpty(null));
-        assertThrows(NullPointerException.class, () -> ObjectUtils.requireNonEmpty(null, "foo"));
+        assertNullPointerException(() -> ObjectUtils.requireNonEmpty(null));
+        assertNullPointerException(() -> ObjectUtils.requireNonEmpty(null, "foo"));
         //
-        assertThrows(IllegalArgumentException.class, () -> ObjectUtils.requireNonEmpty(""));
-        assertThrows(IllegalArgumentException.class, () -> ObjectUtils.requireNonEmpty("", "foo"));
+        assertIllegalArgumentException(() -> ObjectUtils.requireNonEmpty(""));
+        assertIllegalArgumentException(() -> ObjectUtils.requireNonEmpty("", "foo"));
     }
 
     @Test
-    public void testToString_Object() {
-        assertEquals("", ObjectUtils.toString(null) );
-        assertEquals(Boolean.TRUE.toString(), ObjectUtils.toString(Boolean.TRUE) );
+    void testToString_Object() {
+        assertEquals("", ObjectUtils.toString(null));
+        assertEquals(Boolean.TRUE.toString(), ObjectUtils.toString(Boolean.TRUE));
     }
 
     @Test
-    public void testToString_ObjectString() {
-        assertEquals(BAR, ObjectUtils.toString(null, BAR) );
-        assertEquals(Boolean.TRUE.toString(), ObjectUtils.toString(Boolean.TRUE, BAR) );
+    void testToString_Object_String() {
+        assertEquals(BAR, ObjectUtils.toString(null, BAR));
+        assertEquals(Boolean.TRUE.toString(), ObjectUtils.toString(Boolean.TRUE, BAR));
     }
 
     @Test
-    public void testToString_SupplierString() {
+    void testToString_String_Supplier() {
         assertNull(ObjectUtils.toString(null, (Supplier<String>) null));
-        assertNull(ObjectUtils.toString(null, () -> null));
+        assertNull(ObjectUtils.toString(null, Suppliers.nul()));
         // Pretend computing BAR is expensive.
         assertEquals(BAR, ObjectUtils.toString(null, () -> BAR));
         assertEquals(Boolean.TRUE.toString(), ObjectUtils.toString(Boolean.TRUE, () -> BAR));
     }
 
     @Test
-    public void testWaitDuration() {
+    void testToString_Supplier_Supplier() {
+        assertNull(ObjectUtils.toString(NULL_SUPPLIER, (Supplier<String>) null));
+        assertNull(ObjectUtils.toString(Suppliers.nul(), (Supplier<String>) null));
+        assertNull(ObjectUtils.toString(NULL_SUPPLIER, Suppliers.nul()));
+        assertNull(ObjectUtils.toString(Suppliers.nul(), Suppliers.nul()));
+        // Pretend computing BAR is expensive.
+        assertEquals(BAR, ObjectUtils.toString(NULL_SUPPLIER, () -> BAR));
+        assertEquals(BAR, ObjectUtils.toString(Suppliers.nul(), () -> BAR));
+        assertEquals(Boolean.TRUE.toString(), ObjectUtils.toString(() -> Boolean.TRUE, () -> BAR));
+    }
+
+    @Test
+    void testWaitDuration() {
         assertThrows(IllegalMonitorStateException.class, () -> ObjectUtils.wait(new Object(), Duration.ZERO));
     }
 
