@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -28,18 +28,13 @@ import org.junit.jupiter.api.Test;
 /**
  * Test class for {@code ConstantInitializer}.
  */
-public class ConstantInitializerTest extends AbstractLangTest {
+class ConstantInitializerTest extends AbstractLangTest {
     /** Constant for the object managed by the initializer. */
     private static final Integer VALUE = 42;
 
     /** The initializer to be tested. */
     private ConstantInitializer<Integer> init;
 
-    @BeforeEach
-    public void setUp() {
-        init = new ConstantInitializer<>(VALUE);
-    }
-
     /**
      * Helper method for testing equals() and hashCode().
      *
@@ -56,29 +51,28 @@ public class ConstantInitializerTest extends AbstractLangTest {
         }
     }
 
-    /**
-     * Tests whether the correct object is returned.
-     */
-    @Test
-    public void testGetObject() {
-        assertEquals(VALUE, init.getObject(), "Wrong object");
+    @BeforeEach
+    public void setUp() {
+        init = new ConstantInitializer<>(VALUE);
     }
 
     /**
-     * Tests whether get() returns the correct object.
-     *
-     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
+     * Tests equals() if the expected result is false.
      */
     @Test
-    public void testGet() throws ConcurrentException {
-        assertEquals(VALUE, init.get(), "Wrong object");
+    void testEqualsFalse() {
+        ConstantInitializer<Integer> init2 = new ConstantInitializer<>(
+                null);
+        checkEquals(init2, false);
+        init2 = new ConstantInitializer<>(VALUE + 1);
+        checkEquals(init2, false);
     }
 
     /**
      * Tests equals() if the expected result is true.
      */
     @Test
-    public void testEqualsTrue() {
+    void testEqualsTrue() {
         checkEquals(init, true);
         ConstantInitializer<Integer> init2 = new ConstantInitializer<>(
                 Integer.valueOf(VALUE.intValue()));
@@ -88,33 +82,49 @@ public class ConstantInitializerTest extends AbstractLangTest {
         checkEquals(init2, true);
     }
 
-    /**
-     * Tests equals() if the expected result is false.
-     */
-    @Test
-    public void testEqualsFalse() {
-        ConstantInitializer<Integer> init2 = new ConstantInitializer<>(
-                null);
-        checkEquals(init2, false);
-        init2 = new ConstantInitializer<>(VALUE + 1);
-        checkEquals(init2, false);
-    }
-
     /**
      * Tests equals() with objects of other classes.
      */
     @Test
-    public void testEqualsWithOtherObjects() {
+    void testEqualsWithOtherObjects() {
         checkEquals(null, false);
         checkEquals(this, false);
         checkEquals(new ConstantInitializer<>("Test"), false);
     }
 
+    /**
+     * Tests whether get() returns the correct object.
+     *
+     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
+     */
+    @Test
+    void testGet() throws ConcurrentException {
+        assertEquals(VALUE, init.get(), "Wrong object");
+    }
+
+    /**
+     * Tests whether the correct object is returned.
+     */
+    @Test
+    void testGetObject() {
+        assertEquals(VALUE, init.getObject(), "Wrong object");
+    }
+
+    /**
+     * Tests a simple invocation of the isInitialized() method.
+     */
+    @Test
+    void testisInitialized() {
+        assertTrue(init.isInitialized(), "was not initialized before get()");
+        assertEquals(VALUE, init.getObject(), "Wrong object");
+        assertTrue(init.isInitialized(), "was not initialized after get()");
+    }
+
     /**
      * Tests the string representation.
      */
     @Test
-    public void testToString() {
+    void testToString() {
         final String s = init.toString();
         final Pattern pattern = Pattern
                 .compile("ConstantInitializer@-?\\d+ \\[ object = " + VALUE
@@ -126,7 +136,7 @@ public class ConstantInitializerTest extends AbstractLangTest {
      * Tests the string representation if the managed object is null.
      */
     @Test
-    public void testToStringNull() {
+    void testToStringNull() {
         final String s = new ConstantInitializer<>(null).toString();
         assertTrue(s.indexOf("object = null") > 0, "Object not found: " + s);
     }
