@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,6 +18,7 @@ package org.apache.commons.lang3.exception;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertInstanceOf;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
@@ -34,23 +35,21 @@ import org.apache.commons.lang3.tuple.Pair;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
-
 /**
  * Abstract test of an ExceptionContext implementation.
  */
 public abstract class AbstractExceptionContextTest<T extends ExceptionContext & Serializable> extends AbstractLangTest {
 
-    protected static final String TEST_MESSAGE_2 = "This is monotonous";
-    protected static final String TEST_MESSAGE = "Test Message";
-    protected T exceptionContext;
-
     protected static class ObjectWithFaultyToString {
         @Override
         public String toString() {
             throw new RuntimeException("Crap");
         }
     }
+    protected static final String TEST_MESSAGE_2 = "This is monotonous";
+    protected static final String TEST_MESSAGE = "Test Message";
 
+    protected T exceptionContext;
 
     @BeforeEach
     public void setUp() throws Exception {
@@ -63,7 +62,7 @@ public abstract class AbstractExceptionContextTest<T extends ExceptionContext &
     }
 
     @Test
-    public void testAddContextValue() {
+    void testAddContextValue() {
         final String message = exceptionContext.getFormattedExceptionMessage(TEST_MESSAGE);
         assertTrue(message.contains(TEST_MESSAGE));
         assertTrue(message.contains("test1"));
@@ -91,7 +90,72 @@ public abstract class AbstractExceptionContextTest<T extends ExceptionContext &
     }
 
     @Test
-    public void testSetContextValue() {
+    void testGetContextEntries() {
+        assertEquals(5, exceptionContext.getContextEntries().size());
+
+        exceptionContext.addContextValue("test2", "different value");
+
+        final List<Pair<String, Object>> entries = exceptionContext.getContextEntries();
+        assertEquals(6, entries.size());
+        assertEquals("test1", entries.get(0).getKey());
+        assertEquals("test2", entries.get(1).getKey());
+        assertEquals("test Date", entries.get(2).getKey());
+        assertEquals("test Nbr", entries.get(3).getKey());
+        assertEquals("test Poorly written obj", entries.get(4).getKey());
+        assertEquals("test2", entries.get(5).getKey());
+    }
+
+    @Test
+    void testGetContextLabels() {
+        assertEquals(5, exceptionContext.getContextEntries().size());
+
+        exceptionContext.addContextValue("test2", "different value");
+
+        final Set<String> labels = exceptionContext.getContextLabels();
+        assertEquals(6, exceptionContext.getContextEntries().size());
+        assertEquals(5, labels.size());
+        assertTrue(labels.contains("test1"));
+        assertTrue(labels.contains("test2"));
+        assertTrue(labels.contains("test Date"));
+        assertTrue(labels.contains("test Nbr"));
+    }
+
+    @Test
+    void testGetContextValues() {
+        exceptionContext.addContextValue("test2", "different value");
+
+        assertEquals(Collections.singletonList(null), exceptionContext.getContextValues("test1"));
+        assertEquals(Arrays.asList("some value", "different value"), exceptionContext.getContextValues("test2"));
+
+        exceptionContext.setContextValue("test2", "another");
+
+        assertEquals("another", exceptionContext.getFirstContextValue("test2"));
+    }
+
+    @Test
+    void testGetFirstContextValue() {
+        exceptionContext.addContextValue("test2", "different value");
+
+        assertNull(exceptionContext.getFirstContextValue("test1"));
+        assertEquals("some value", exceptionContext.getFirstContextValue("test2"));
+        assertNull(exceptionContext.getFirstContextValue("crap"));
+
+        exceptionContext.setContextValue("test2", "another");
+
+        assertEquals("another", exceptionContext.getFirstContextValue("test2"));
+    }
+
+    @Test
+    void testJavaSerialization() {
+        exceptionContext.setContextValue("test Poorly written obj", "serializable replacement");
+
+        final T clone = SerializationUtils.deserialize(SerializationUtils.serialize(exceptionContext));
+
+        assertEquals(exceptionContext.getFormattedExceptionMessage(null), clone.getFormattedExceptionMessage(null));
+    }
+
+    @Test
+    void testSetContextValue() {
         exceptionContext.addContextValue("test2", "different value");
         exceptionContext.setContextValue("test3", "3");
 
@@ -101,7 +165,7 @@ public abstract class AbstractExceptionContextTest<T extends ExceptionContext &
         assertTrue(message.contains("Crap"));
 
         assertNull(exceptionContext.getFirstContextValue("crap"));
-        assertTrue(exceptionContext.getFirstContextValue("test Poorly written obj") instanceof ObjectWithFaultyToString);
+        assertInstanceOf(ObjectWithFaultyToString.class, exceptionContext.getFirstContextValue("test Poorly written obj"));
 
         assertEquals(7, exceptionContext.getContextEntries().size());
         assertEquals(6, exceptionContext.getContextLabels().size());
@@ -122,69 +186,4 @@ public abstract class AbstractExceptionContextTest<T extends ExceptionContext &
         final String contextMessage = exceptionContext.getFormattedExceptionMessage(null);
         assertFalse(contextMessage.contains(TEST_MESSAGE));
     }
-
-    @Test
-    public void testGetFirstContextValue() {
-        exceptionContext.addContextValue("test2", "different value");
-
-        assertNull(exceptionContext.getFirstContextValue("test1"));
-        assertEquals("some value", exceptionContext.getFirstContextValue("test2"));
-        assertNull(exceptionContext.getFirstContextValue("crap"));
-
-        exceptionContext.setContextValue("test2", "another");
-
-        assertEquals("another", exceptionContext.getFirstContextValue("test2"));
-    }
-
-    @Test
-    public void testGetContextValues() {
-        exceptionContext.addContextValue("test2", "different value");
-
-        assertEquals(Collections.singletonList(null), exceptionContext.getContextValues("test1"));
-        assertEquals(Arrays.asList("some value", "different value"), exceptionContext.getContextValues("test2"));
-
-        exceptionContext.setContextValue("test2", "another");
-
-        assertEquals("another", exceptionContext.getFirstContextValue("test2"));
-    }
-
-    @Test
-    public void testGetContextLabels() {
-        assertEquals(5, exceptionContext.getContextEntries().size());
-
-        exceptionContext.addContextValue("test2", "different value");
-
-        final Set<String> labels = exceptionContext.getContextLabels();
-        assertEquals(6, exceptionContext.getContextEntries().size());
-        assertEquals(5, labels.size());
-        assertTrue(labels.contains("test1"));
-        assertTrue(labels.contains("test2"));
-        assertTrue(labels.contains("test Date"));
-        assertTrue(labels.contains("test Nbr"));
-    }
-
-    @Test
-    public void testGetContextEntries() {
-        assertEquals(5, exceptionContext.getContextEntries().size());
-
-        exceptionContext.addContextValue("test2", "different value");
-
-        final List<Pair<String, Object>> entries = exceptionContext.getContextEntries();
-        assertEquals(6, entries.size());
-        assertEquals("test1", entries.get(0).getKey());
-        assertEquals("test2", entries.get(1).getKey());
-        assertEquals("test Date", entries.get(2).getKey());
-        assertEquals("test Nbr", entries.get(3).getKey());
-        assertEquals("test Poorly written obj", entries.get(4).getKey());
-        assertEquals("test2", entries.get(5).getKey());
-    }
-
-    @Test
-    public void testJavaSerialization() {
-        exceptionContext.setContextValue("test Poorly written obj", "serializable replacement");
-
-        final T clone = SerializationUtils.deserialize(SerializationUtils.serialize(exceptionContext));
-
-        assertEquals(exceptionContext.getFormattedExceptionMessage(null), clone.getFormattedExceptionMessage(null));
-    }
 }
