@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -17,10 +17,9 @@
 package org.apache.commons.lang3.reflect.testbed;
 
 /**
- * @version $Id: Bar.java 1510301 2013-08-04 18:40:48Z mbenson $
  */
 public interface Bar {
-    public static final String VALUE = "bar";
+    String VALUE = "bar";
 
     void doIt();
 }
