@@ -30,6 +30,13 @@ import java.lang.reflect.Modifier;
 import java.text.DateFormat;
 import java.text.ParseException;
 import java.text.SimpleDateFormat;
+import java.time.Instant;
+import java.time.LocalDateTime;
+import java.time.OffsetDateTime;
+import java.time.ZoneId;
+import java.time.ZoneOffset;
+import java.time.ZonedDateTime;
+import java.time.temporal.ChronoUnit;
 import java.util.Calendar;
 import java.util.Date;
 import java.util.GregorianCalendar;
@@ -37,13 +44,18 @@ import java.util.Iterator;
 import java.util.Locale;
 import java.util.NoSuchElementException;
 import java.util.TimeZone;
+import java.util.stream.Stream;
 
 import org.apache.commons.lang3.AbstractLangTest;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.Arguments;
+import org.junit.jupiter.params.provider.MethodSource;
 import org.junitpioneer.jupiter.DefaultLocale;
+import org.junitpioneer.jupiter.DefaultTimeZone;
 import org.junitpioneer.jupiter.ReadsDefaultLocale;
 import org.junitpioneer.jupiter.WritesDefaultLocale;
 
@@ -54,8 +66,9 @@ import org.junitpioneer.jupiter.WritesDefaultLocale;
 @WritesDefaultLocale
 class DateUtilsTest extends AbstractLangTest {
 
+    private static final TimeZone TIME_ZONE_NY = TimeZones.getTimeZone("America/New_York");
     private static final TimeZone TIME_ZONE_DEFAULT = TimeZone.getDefault();
-    private static final TimeZone TIME_ZONE_MET = TimeZone.getTimeZone("MET");
+    private static final TimeZone TIME_ZONE_MET = TimeZones.getTimeZone("MET");
     private static Date BASE_DATE;
 
     /**
@@ -124,6 +137,84 @@ class DateUtilsTest extends AbstractLangTest {
         BASE_DATE = cal.getTime();
     }
 
+    private static Stream<Arguments> testToLocalDateTimeTimeZone() {
+        // @formatter:off
+        return Stream.of(
+                // [1]
+                Arguments.of(
+                        // -292275055-05-16T16:47:04.192
+                        LocalDateTime.of(-292275055, 5, 16, 16, 47, 04, 192_000_000),
+                        new Date(Long.MIN_VALUE),
+                        TimeZones.GMT
+                ),
+                // [2]
+                Arguments.of(
+                        // +292278994-08-17T07:12:55.807
+                        LocalDateTime.of(292278994, 8, 17, 7, 12, 55, 807_000_000),
+                        new Date(Long.MAX_VALUE),
+                        TimeZones.GMT
+                ),
+                // [3]
+                Arguments.of(
+                        LocalDateTime.ofInstant(Instant.EPOCH, TimeZones.GMT.toZoneId()),
+                        Date.from(LocalDateTime.of(1970, 1, 1, 0, 0).atOffset(ZoneOffset.UTC).toInstant()),
+                        TimeZones.GMT
+                ),
+                // [4]
+                Arguments.of(
+                        LocalDateTime.ofInstant(Instant.EPOCH.minus(1, ChronoUnit.DAYS), TimeZones.GMT.toZoneId()),
+                        Date.from(LocalDateTime.of(1969, 12, 31, 0, 0).atOffset(ZoneOffset.UTC).toInstant()),
+                        TimeZones.GMT
+                ),
+                // [5]
+                Arguments.of(
+                        LocalDateTime.ofInstant(
+                                java.sql.Timestamp.valueOf("2000-01-01 12:30:45").toInstant(),
+                                TIME_ZONE_NY.toZoneId()
+                        ),
+                        java.sql.Timestamp.valueOf("2000-01-01 12:30:45"),
+                        TIME_ZONE_NY
+                ),
+                // [6]
+                Arguments.of(
+                        LocalDateTime.ofInstant(
+                                java.sql.Timestamp.valueOf("2023-03-12 02:30:00").toInstant(),
+                                TIME_ZONE_NY.toZoneId()
+                        ),
+                        java.sql.Timestamp.valueOf("2023-03-12 02:30:00"),
+                        TIME_ZONE_NY
+                ),
+                // [7]
+                Arguments.of(
+                        LocalDateTime.ofInstant(
+                                java.sql.Timestamp.valueOf("2023-03-12 02:30:00").toInstant(),
+                                TimeZone.getDefault().toZoneId()
+                        ),
+                        java.sql.Timestamp.valueOf("2023-03-12 02:30:00"),
+                        null
+                ),
+                // [8]
+                Arguments.of(
+                        LocalDateTime.of(2022, 12, 31, 19, 0),
+                        Date.from(LocalDateTime.of(2023, 1, 1, 0, 0).atOffset(ZoneOffset.UTC).toInstant()),
+                        TIME_ZONE_NY
+                ),
+                // [9]
+                Arguments.of(
+                        LocalDateTime.of(2023, 3, 12, 3, 0),
+                        Date.from(LocalDateTime.of(2023, 3, 12, 7, 0).atOffset(ZoneOffset.UTC).toInstant()),
+                        TIME_ZONE_NY
+                ),
+                // [10]
+                Arguments.of(
+                        LocalDateTime.of(2023, 1, 1, 14, 0),
+                        Date.from(LocalDateTime.of(2023, 1, 1, 0, 0).atOffset(ZoneOffset.UTC).toInstant()),
+                        TimeZones.getTimeZone("Pacific/Kiritimati")
+                )
+        );
+        // @formatter:on
+    }
+
     private DateFormat dateParser;
     private DateFormat dateTimeParser;
     private Date dateAmPm1;
@@ -157,7 +248,6 @@ class DateUtilsTest extends AbstractLangTest {
         TimeZone.setDefault(TIME_ZONE_DEFAULT);
         dateTimeParser.setTimeZone(TIME_ZONE_DEFAULT);
     }
-
     private void assertDate(final Date date, final int year, final int month, final int day, final int hour, final int min, final int sec, final int mil) {
         final GregorianCalendar cal = new GregorianCalendar();
         cal.setTime(date);
@@ -169,12 +259,10 @@ class DateUtilsTest extends AbstractLangTest {
         assertEquals(sec, cal.get(Calendar.SECOND));
         assertEquals(mil, cal.get(Calendar.MILLISECOND));
     }
-
     @BeforeEach
     public void setUp() throws Exception {
         dateParser = new SimpleDateFormat("MMM dd, yyyy", Locale.ENGLISH);
         dateTimeParser = new SimpleDateFormat("MMM dd, yyyy H:mm:ss.SSS", Locale.ENGLISH);
-
         dateAmPm1 = dateTimeParser.parse("February 3, 2002 01:10:00.000");
         dateAmPm2 = dateTimeParser.parse("February 3, 2002 11:10:00.000");
         dateAmPm3 = dateTimeParser.parse("February 3, 2002 13:10:00.000");
@@ -675,8 +763,8 @@ class DateUtilsTest extends AbstractLangTest {
 
     @Test
     void testIsSameInstant_Cal() {
-        final GregorianCalendar cala = new GregorianCalendar(TimeZone.getTimeZone("GMT+1"));
-        final GregorianCalendar calb = new GregorianCalendar(TimeZone.getTimeZone("GMT-1"));
+        final GregorianCalendar cala = new GregorianCalendar(TimeZones.getTimeZone("GMT+1"));
+        final GregorianCalendar calb = new GregorianCalendar(TimeZones.getTimeZone("GMT-1"));
         cala.set(2004, Calendar.JULY, 9, 13, 45, 0);
         cala.set(Calendar.MILLISECOND, 0);
         calb.set(2004, Calendar.JULY, 9, 13, 45, 0);
@@ -732,8 +820,8 @@ class DateUtilsTest extends AbstractLangTest {
 
     @Test
     void testIsSameLocalTime_Cal() {
-        final GregorianCalendar cala = new GregorianCalendar(TimeZone.getTimeZone("GMT+1"));
-        final GregorianCalendar calb = new GregorianCalendar(TimeZone.getTimeZone("GMT-1"));
+        final GregorianCalendar cala = new GregorianCalendar(TimeZones.getTimeZone("GMT+1"));
+        final GregorianCalendar calb = new GregorianCalendar(TimeZones.getTimeZone("GMT-1"));
         cala.set(2004, Calendar.JULY, 9, 13, 45, 0);
         cala.set(Calendar.MILLISECOND, 0);
         calb.set(2004, Calendar.JULY, 9, 13, 45, 0);
@@ -1232,10 +1320,73 @@ class DateUtilsTest extends AbstractLangTest {
         assertNullPointerException(() -> DateUtils.toCalendar(date1, null));
     }
 
+    @ParameterizedTest
+    @MethodSource("testToLocalDateTimeTimeZone")
+    @DefaultLocale(language = "en", country = "US")
+    @DefaultTimeZone(TimeZones.GMT_ID)
+    void testToLocalDateTime(final LocalDateTime expected, final Date date, final TimeZone timeZone) {
+        assertEquals(LocalDateTime.ofInstant(date.toInstant(), ZoneId.systemDefault()), DateUtils.toLocalDateTime(date),
+                () -> String.format("expected = %s, date = %s, timeZone = %s, TimeZone.getDefault() = %s", expected, date, timeZone, TimeZone.getDefault()));
+    }
+
+    @ParameterizedTest
+    @MethodSource("testToLocalDateTimeTimeZone")
+    @DefaultLocale(language = "en", country = "US")
+    @DefaultTimeZone(TimeZones.GMT_ID)
+    void testToLocalDateTimeTimeZone(final LocalDateTime expected, final Date date, final TimeZone timeZone) {
+        assertEquals(expected, DateUtils.toLocalDateTime(date, timeZone),
+                () -> String.format("expected = %s, date = %s, timeZone = %s, TimeZone.getDefault() = %s", expected, date, timeZone, TimeZone.getDefault()));
+    }
+
+    @ParameterizedTest
+    @MethodSource("testToLocalDateTimeTimeZone")
+    @DefaultLocale(language = "en", country = "US")
+    @DefaultTimeZone(TimeZones.GMT_ID)
+    void testToOffsetDateTime(final LocalDateTime expected, final Date date, final TimeZone timeZone) {
+        final OffsetDateTime offsetDateTime = DateUtils.toOffsetDateTime(date);
+        assertEquals(OffsetDateTime.ofInstant(date.toInstant(), ZoneId.systemDefault()), offsetDateTime,
+                () -> String.format("expected = %s, date = %s, timeZone = %s, TimeZone.getDefault() = %s", expected, date, timeZone, TimeZone.getDefault()));
+    }
+
+    @ParameterizedTest
+    @MethodSource("testToLocalDateTimeTimeZone")
+    @DefaultLocale(language = "en", country = "US")
+    @DefaultTimeZone(TimeZones.GMT_ID)
+    void testToOffsetDateTimeTimeZone(final LocalDateTime expected, final Date date, final TimeZone timeZone) {
+        assertEquals(expected, DateUtils.toOffsetDateTime(date, timeZone).toLocalDateTime(),
+                () -> String.format("expected = %s, date = %s, timeZone = %s, TimeZone.getDefault() = %s", expected, date, timeZone, TimeZone.getDefault()));
+    }
+
+    @ParameterizedTest
+    @MethodSource("testToLocalDateTimeTimeZone")
+    @DefaultLocale(language = "en", country = "US")
+    @DefaultTimeZone(TimeZones.GMT_ID)
+    void testToZonedDateTime(final LocalDateTime expected, final Date date, final TimeZone timeZone) {
+        final ZonedDateTime zonedDateTime = DateUtils.toZonedDateTime(date);
+        assertEquals(ZonedDateTime.ofInstant(date.toInstant(), ZoneId.systemDefault()), zonedDateTime,
+                () -> String.format("expected = %s, date = %s, timeZone = %s, TimeZone.getDefault() = %s", expected, date, timeZone, TimeZone.getDefault()));
+        // Using atZone()
+        assertEquals(date.toInstant().atZone(ZoneId.systemDefault()), zonedDateTime,
+                () -> String.format("expected = %s, date = %s, timeZone = %s, TimeZone.getDefault() = %s", expected, date, timeZone, TimeZone.getDefault()));
+    }
+
+    @ParameterizedTest
+    @MethodSource("testToLocalDateTimeTimeZone")
+    @DefaultLocale(language = "en", country = "US")
+    @DefaultTimeZone(TimeZones.GMT_ID)
+    void testToZonedDateTimeTimeZone(final LocalDateTime expected, final Date date, final TimeZone timeZone) {
+        final ZonedDateTime zonedDateTime = DateUtils.toZonedDateTime(date, timeZone);
+        assertEquals(expected, zonedDateTime.toOffsetDateTime().toLocalDateTime(),
+                () -> String.format("expected = %s, date = %s, timeZone = %s, TimeZone.getDefault() = %s", expected, date, timeZone, TimeZone.getDefault()));
+        // Using atZone()
+        assertEquals(date.toInstant().atZone(TimeZones.toTimeZone(timeZone).toZoneId()), zonedDateTime,
+                () -> String.format("expected = %s, date = %s, timeZone = %s, TimeZone.getDefault() = %s", expected, date, timeZone, TimeZone.getDefault()));
+    }
+
     /**
-     * Tests various values with the trunc method
+     * Tests various values with the trunc method.
      *
-     * @throws Exception so we don't have to catch it
+     * @throws Exception so we don't have to catch it.
      */
     @Test
     void testTruncate() throws Exception {
@@ -1426,7 +1577,7 @@ class DateUtilsTest extends AbstractLangTest {
     @Test
     void testTruncateLang59() {
         // Set TimeZone to Mountain Time
-        final TimeZone denverZone = TimeZone.getTimeZone("America/Denver");
+        final TimeZone denverZone = TimeZones.getTimeZone("America/Denver");
         TimeZone.setDefault(denverZone);
         final DateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss.SSS XXX");
         format.setTimeZone(denverZone);
